betty.cache.memory module - Betty 0.4.0a3 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.cache.memory module

Provide caching that stores cache items in volatile memory.

final class betty.cache.memory.MemoryCache

  Bases: `_CommonCacheBase`[`_CacheItemValueContraT`], `Generic`[`_CacheItemValueContraT`]

  Provide a cache that stores cache items in volatile memory.

  __init__(localizer, *, scopes=None, _store=None)